@@ -1,6 +1,4 @@
 mod append;
-mod column;
-mod command;
 mod describe;
 mod drop;
 mod drop_duplicates;
@@ -18,7 +16,6 @@ mod rename;
 mod sample;
 mod shape;
 mod slice;
-mod sort;
 mod take;
 mod to_csv;
 mod to_df;
@@ -29,8 +26,6 @@ mod with_column;
 use nu_protocol::engine::StateWorkingSet;
 
 pub use append::AppendDF;
-pub use column::ColumnDF;
-pub use command::Dataframe;
 pub use describe::DescribeDF;
 pub use drop::DropDF;
 pub use drop_duplicates::DropDuplicates;
@@ -48,7 +43,6 @@ pub use rename::RenameDF;
 pub use sample::SampleDF;
 pub use shape::ShapeDF;
 pub use slice::SliceDF;
-pub use sort::SortDF;
 pub use take::TakeDF;
 pub use to_csv::ToCSV;
 pub use to_df::ToDataFrame;
@@ -69,8 +63,6 @@ pub fn add_eager_decls(working_set: &mut StateWorkingSet) {
     // Dataframe commands
     bind_command!(
         AppendDF,
-        ColumnDF,
-        Dataframe,
         DataTypes,
         DescribeDF,
         DropDF,
@@ -88,7 +80,6 @@ pub fn add_eager_decls(working_set: &mut StateWorkingSet) {
         SampleDF,
         ShapeDF,
         SliceDF,
-        SortDF,
         TakeDF,
         ToCSV,
         ToDataFrame,
