@@ -19,13 +19,16 @@ impl Command for ValueCount {
     }
 
     fn signature(&self) -> Signature {
-        Signature::build(self.name()).category(Category::Custom("dataframe".into()))
+        Signature::build(self.name())
+            .input_type(Type::Custom("dataframe".into()))
+            .output_type(Type::Custom("dataframe".into()))
+            .category(Category::Custom("dataframe".into()))
     }
 
     fn examples(&self) -> Vec<Example> {
         vec![Example {
             description: "Calculates value counts",
-            example: "[5 5 5 5 6 6] | to-df | value-counts",
+            example: "[5 5 5 5 6 6] | into df | value-counts",
             result: Some(
                 NuDataFrame::try_from_columns(vec![
                     Column::new(
@@ -43,14 +46,6 @@ impl Command for ValueCount {
         }]
     }
 
-    fn input_type(&self) -> Type {
-        Type::Custom("dataframe".into())
-    }
-
-    fn output_type(&self) -> Type {
-        Type::Custom("dataframe".into())
-    }
-
     fn run(
         &self,
         engine_state: &EngineState,
