@@ -94,7 +94,7 @@ fn reject(
                 let mut vals = vec![];
 
                 for path in &keep_columns {
-                    let fetcher = input_val.clone().follow_cell_path(&path.members);
+                    let fetcher = input_val.clone().follow_cell_path(&path.members, false);
 
                     if let Ok(value) = fetcher {
                         cols.push(path.into_string());
@@ -135,7 +135,7 @@ fn reject(
                 let mut vals = vec![];
 
                 for path in &keep_columns {
-                    let fetcher = input_val.clone().follow_cell_path(&path.members)?;
+                    let fetcher = input_val.clone().follow_cell_path(&path.members, false)?;
                     cols.push(path.into_string());
                     vals.push(fetcher);
                 }
@@ -151,7 +151,7 @@ fn reject(
             let mut vals = vec![];
 
             for cell_path in &keep_columns {
-                let result = v.clone().follow_cell_path(&cell_path.members)?;
+                let result = v.clone().follow_cell_path(&cell_path.members, false)?;
 
                 cols.push(cell_path.into_string());
                 vals.push(result);
@@ -205,3 +205,13 @@ fn reject_record_columns(cols: &mut Vec<String>, vals: &mut Vec<Value>, rejects:
         }
     }
 }
+
+#[cfg(test)]
+mod test {
+    #[test]
+    fn test_examples() {
+        use super::Reject;
+        use crate::test_examples;
+        test_examples(Reject {})
+    }
+}
