@@ -1,3 +1,4 @@
+mod bytes;
 mod charting;
 mod conversions;
 mod core_commands;
@@ -13,15 +14,18 @@ mod formats;
 mod generators;
 mod hash;
 mod math;
+mod misc;
 mod network;
 mod path;
 mod platform;
 mod random;
 mod shells;
+mod sort_utils;
 mod strings;
 mod system;
 mod viewers;
 
+pub use bytes::*;
 pub use charting::*;
 pub use conversions::*;
 pub use core_commands::*;
@@ -38,11 +42,13 @@ pub use formats::*;
 pub use generators::*;
 pub use hash::*;
 pub use math::*;
+pub use misc::*;
 pub use network::*;
 pub use path::*;
 pub use platform::*;
 pub use random::*;
 pub use shells::*;
+pub use sort_utils::*;
 pub use strings::*;
 pub use system::*;
 pub use viewers::*;
