@@ -130,12 +130,12 @@ lazy_static! {
     AnsiCode{ short_name: Some("dgrd"), long_name: "dark_gray_dimmed", code: Color::DarkGray.dimmed().prefix().to_string()},
     AnsiCode{ short_name: Some("dgrr"), long_name: "dark_gray_reverse", code: Color::DarkGray.reverse().prefix().to_string()},
 
-    AnsiCode{ short_name: Some("der"), long_name: "default", code: Color::Default.prefix().to_string()},
-    AnsiCode{ short_name: Some("deb"), long_name: "default_bold", code: Color::Default.bold().prefix().to_string()},
-    AnsiCode{ short_name: Some("deu"), long_name: "default_underline", code: Color::Default.underline().prefix().to_string()},
-    AnsiCode{ short_name: Some("dei"), long_name: "default_italic", code: Color::Default.italic().prefix().to_string()},
-    AnsiCode{ short_name: Some("ded"), long_name: "default_dimmed", code: Color::Default.dimmed().prefix().to_string()},
-    AnsiCode{ short_name: Some("der"), long_name: "default_reverse", code: Color::Default.reverse().prefix().to_string()},
+    AnsiCode{ short_name: Some("def"), long_name: "default", code: Color::Default.prefix().to_string()},
+    AnsiCode{ short_name: Some("defb"), long_name: "default_bold", code: Color::Default.bold().prefix().to_string()},
+    AnsiCode{ short_name: Some("defu"), long_name: "default_underline", code: Color::Default.underline().prefix().to_string()},
+    AnsiCode{ short_name: Some("defi"), long_name: "default_italic", code: Color::Default.italic().prefix().to_string()},
+    AnsiCode{ short_name: Some("defd"), long_name: "default_dimmed", code: Color::Default.dimmed().prefix().to_string()},
+    AnsiCode{ short_name: Some("defr"), long_name: "default_reverse", code: Color::Default.reverse().prefix().to_string()},
 
     AnsiCode{ short_name: None, long_name: "reset", code: "\x1b[0m".to_owned()},
     // Reference for ansi codes https://gist.github.com/fnky/458719343aabd01cfb17a3a4f7296797
@@ -317,7 +317,7 @@ Format: #
         let list: bool = call.has_flag("list");
         let escape: bool = call.has_flag("escape");
         let osc: bool = call.has_flag("osc");
-        let use_ansi_coloring = stack.get_config()?.use_ansi_coloring;
+        let use_ansi_coloring = engine_state.get_config().use_ansi_coloring;
 
         if list {
             return generate_ansi_code_list(engine_state, call.head, use_ansi_coloring);
@@ -375,15 +375,34 @@ Format: #
             // OCS's need to end with a bell '\x07' char
             format!("\x1b]{};", code_string)
         } else if param_is_valid_string {
-            match str_to_ansi(&code_string) {
-                Some(c) => c,
-                None => {
-                    return Err(ShellError::UnsupportedInput(
-                        String::from("Unknown ansi code"),
-                        call.positional_nth(0)
-                            .expect("Unexpected missing argument")
-                            .span,
-                    ))
+            // parse hex colors like #00FF00
+            if code_string.starts_with('#') {
+                match nu_color_config::color_from_hex(&code_string) {
+                    Ok(color) => match color {
+                        Some(c) => c.prefix().to_string(),
+                        None => Color::White.prefix().to_string(),
+                    },
+                    Err(err) => {
+                        return Err(ShellError::GenericError(
+                            "error parsing hex color".to_string(),
+                            format!("{}", err),
+                            Some(code.span()?),
+                            None,
+                            Vec::new(),
+                        ));
+                    }
+                }
+            } else {
+                match str_to_ansi(&code_string) {
+                    Some(c) => c,
+                    None => {
+                        return Err(ShellError::UnsupportedInput(
+                            String::from("Unknown ansi code"),
+                            call.positional_nth(0)
+                                .expect("Unexpected missing argument")
+                                .span,
+                        ))
+                    }
                 }
             }
         } else {
