@@ -194,9 +194,6 @@ impl ExternalCommand {
                 let (stderr_tx, stderr_rx) = mpsc::sync_channel(OUTPUT_BUFFERS_IN_FLIGHT);
                 let (exit_code_tx, exit_code_rx) = mpsc::channel();
 
-                #[cfg(unix)]
-                let (exit_status_tx, exit_status_rx) = mpsc::channel();
-
                 std::thread::spawn(move || {
                     // If this external is not the last expression, then its output is piped to a channel
                     // and we create a ListStream that can be consumed
@@ -286,9 +283,6 @@ impl ExternalCommand {
                             span,
                         )),
                         Ok(x) => {
-                            #[cfg(unix)]
-                            let _ = exit_status_tx.send(x);
-
                             if let Some(code) = x.code() {
                                 let _ = exit_code_tx.send(Value::Int {
                                     val: code as i64,
@@ -310,26 +304,6 @@ impl ExternalCommand {
                 let stderr_receiver = ChannelReceiver::new(stderr_rx);
                 let exit_code_receiver = ValueReceiver::new(exit_code_rx);
 
-                #[cfg(unix)]
-                {
-                    use signal_hook::low_level::signal_name;
-                    use std::os::unix::process::ExitStatusExt;
-                    use std::time::Duration;
-
-                    // The receiver will block 100ms if there's no sender
-                    if let Ok(status) = exit_status_rx.recv_timeout(Duration::from_millis(100)) {
-                        if status.core_dumped() {
-                            if let Some(sig) = status.signal().and_then(signal_name) {
-                                return Err(ShellError::ExternalCommand(
-                                    format!("{sig} (core dumped)"),
-                                    "Child process core dumped".to_string(),
-                                    span,
-                                ));
-                            }
-                        }
-                    }
-                }
-
                 Ok(PipelineData::ExternalStream {
                     stdout: if redirect_stdout {
                         Some(RawStream::new(
@@ -428,7 +402,7 @@ impl ExternalCommand {
 
     /// Spawn a command without shelling out to an external shell
     pub fn spawn_simple_command(&self, cwd: &str) -> Result<std::process::Command, ShellError> {
-        let head = trim_enclosing_quotes(&self.name.item);
+        let (head, _) = trim_enclosing_quotes(&self.name.item);
         let head = nu_path::expand_to_real_path(head)
             .to_string_lossy()
             .to_string();
@@ -436,8 +410,9 @@ impl ExternalCommand {
         let mut process = std::process::Command::new(&head);
 
         for arg in self.args.iter() {
+            let (trimmed_args, run_glob_expansion) = trim_enclosing_quotes(&arg.item);
             let mut arg = Spanned {
-                item: remove_quotes(trim_enclosing_quotes(&arg.item)),
+                item: remove_quotes(trimmed_args),
                 span: arg.span,
             };
 
@@ -447,7 +422,7 @@ impl ExternalCommand {
 
             let cwd = PathBuf::from(cwd);
 
-            if arg.item.contains('*') {
+            if arg.item.contains('*') && run_glob_expansion {
                 if let Ok((prefix, matches)) =
                     nu_engine::glob_from(&arg, &cwd, self.name.span, None)
                 {
@@ -542,14 +517,14 @@ fn shell_arg_escape(arg: &str) -> String {
     }
 }
 
-fn trim_enclosing_quotes(input: &str) -> String {
+fn trim_enclosing_quotes(input: &str) -> (String, bool) {
     let mut chars = input.chars();
 
     match (chars.next(), chars.next_back()) {
-        (Some('"'), Some('"')) => chars.collect(),
-        (Some('\''), Some('\'')) => chars.collect(),
-        (Some('`'), Some('`')) => chars.collect(),
-        _ => input.to_string(),
+        (Some('"'), Some('"')) => (chars.collect(), false),
+        (Some('\''), Some('\'')) => (chars.collect(), false),
+        (Some('`'), Some('`')) => (chars.collect(), true),
+        _ => (input.to_string(), true),
     }
 }
 
